py-romanify
===========

Convertor of roman/arabic numerals 

.. include:: installation.rst

.. include:: usage.rst

.. include:: changelog.rst

.. toctree::
    :maxdepth: 2

    installation
    usage
    changelog
